@@ -21,6 +21,7 @@
 __docformat__ = "restructuredtext en"
 
 import os
+import sys
 from os.path import join
 
 distname = "logilab-common"
@@ -28,7 +29,7 @@ modname = "common"
 subpackage_of = "logilab"
 subpackage_master = True
 
-numversion = (1, 8, 3)
+numversion = (1, 9, 3)
 version = ".".join([str(num) for num in numversion])
 
 license = "LGPL"  # 2.1 or later
@@ -55,6 +56,9 @@ tests_require = [
 if os.name == "nt":
     install_requires.append("colorama")
 
+if sys.version_info < (3, 8):
+    install_requires.append("importlib_metadata")
+
 classifiers = [
     "Topic :: Utilities",
     "Programming Language :: Python",
